@@ -25,37 +25,14 @@
 
 #include "goaprovider.h"
 #include "goaprovider-priv.h"
-#include "goaoauthprovider.h"
 #include "goaflickrprovider.h"
 #include "goaobjectskeletonutils.h"
 
-/**
- * GoaFlickrProvider:
- *
- * The #GoaFlickrProvider structure contains only private data and should
- * only be accessed using the provided API.
- */
 struct _GoaFlickrProvider
 {
-  /*< private >*/
   GoaOAuthProvider parent_instance;
 };
 
-typedef struct _GoaFlickrProviderClass GoaFlickrProviderClass;
-
-struct _GoaFlickrProviderClass
-{
-  GoaOAuthProviderClass parent_class;
-};
-
-/**
- * SECTION:goaflickrprovider
- * @title: GoaFlickrProvider
- * @short_description: A provider for Flickr
- *
- * #GoaFlickrProvider is used for handling Flickr accounts.
- */
-
 G_DEFINE_TYPE_WITH_CODE (GoaFlickrProvider, goa_flickr_provider, GOA_TYPE_OAUTH_PROVIDER,
                          goa_provider_ensure_extension_points_registered ();
                          g_io_extension_point_implement (GOA_PROVIDER_EXTENSION_POINT_NAME,
@@ -105,35 +82,25 @@ get_consumer_secret (GoaOAuthProvider *oauth_provider)
 static const gchar *
 get_request_uri (GoaOAuthProvider *oauth_provider)
 {
-  return "https://www.flickr.com/services/oauth/request_token";
+  return "https://m.flickr.com/services/oauth/request_token";
 }
 
 static const gchar *
 get_authorization_uri (GoaOAuthProvider *oauth_provider)
 {
-  return "https://www.flickr.com/services/oauth/authorize";
+  return "https://m.flickr.com/services/oauth/authorize";
 }
 
 static const gchar *
 get_token_uri (GoaOAuthProvider *oauth_provider)
 {
-  return "https://www.flickr.com/services/oauth/access_token";
+  return "https://m.flickr.com/services/oauth/access_token";
 }
 
 static const gchar *
 get_callback_uri (GoaOAuthProvider *oauth_provider)
 {
-  /* Should match the URI specified in the Flickr App
-   * Garden in order to detect when the user denied access via
-   * the OAuth1 web page.
-   */
-  return "https://www.gnome.org/";
-}
-
-static const gchar *
-get_authentication_cookie (GoaOAuthProvider *oauth_provider)
-{
-  return "cookie_session";
+  return "https://www.gnome.org/goa-1.0/oauth";
 }
 
 /* ---------------------------------------------------------------------------------------------------- */
@@ -401,7 +368,6 @@ goa_flickr_provider_class_init (GoaFlickrProviderClass *klass)
   oauth_class->get_authorization_uri    = get_authorization_uri;
   oauth_class->get_token_uri            = get_token_uri;
   oauth_class->get_callback_uri         = get_callback_uri;
-  oauth_class->get_authentication_cookie = get_authentication_cookie;
   oauth_class->parse_request_token_error = parse_request_token_error;
   oauth_class->add_account_key_values    = add_account_key_values;
 }
