@@ -25,37 +25,14 @@
 #include "goaprovider.h"
 #include "goaprovider-priv.h"
 #include "goaoauth2provider.h"
-#include "goaoauth2provider-priv.h"
 #include "goagoogleprovider.h"
 #include "goaobjectskeletonutils.h"
 
-/**
- * GoaGoogleProvider:
- *
- * The #GoaGoogleProvider structure contains only private data and should
- * only be accessed using the provided API.
- */
 struct _GoaGoogleProvider
 {
-  /*< private >*/
   GoaOAuth2Provider parent_instance;
 };
 
-typedef struct _GoaGoogleProviderClass GoaGoogleProviderClass;
-
-struct _GoaGoogleProviderClass
-{
-  GoaOAuth2ProviderClass parent_class;
-};
-
-/**
- * SECTION:goagoogleprovider
- * @title: GoaGoogleProvider
- * @short_description: A provider for Google
- *
- * #GoaGoogleProvider is used for handling Google accounts.
- */
-
 G_DEFINE_TYPE_WITH_CODE (GoaGoogleProvider, goa_google_provider, GOA_TYPE_OAUTH2_PROVIDER,
                          goa_provider_ensure_extension_points_registered ();
                          g_io_extension_point_implement (GOA_PROVIDER_EXTENSION_POINT_NAME,
@@ -179,12 +156,6 @@ get_client_secret (GoaOAuth2Provider *oauth2_provider)
   return GOA_GOOGLE_CLIENT_SECRET;
 }
 
-static const gchar *
-get_authentication_cookie (GoaOAuth2Provider *oauth2_provider)
-{
-  return "LSID";
-}
-
 /* ---------------------------------------------------------------------------------------------------- */
 
 static gchar *
@@ -355,6 +326,7 @@ build_object (GoaProvider         *provider,
                         "smtp-user-name",  email_address,
                         "smtp-use-auth",   TRUE,
                         "smtp-auth-xoauth2", TRUE,
+                        "smtp-use-ssl",    TRUE,
                         "smtp-use-tls",    TRUE,
                         NULL);
           goa_object_skeleton_set_mail (object, mail);
@@ -492,7 +464,6 @@ goa_google_provider_class_init (GoaGoogleProviderClass *klass)
   provider_class->get_credentials_generation = get_credentials_generation;
 
   oauth2_class = GOA_OAUTH2_PROVIDER_CLASS (klass);
-  oauth2_class->get_authentication_cookie = get_authentication_cookie;
   oauth2_class->get_authorization_uri     = get_authorization_uri;
   oauth2_class->get_client_id             = get_client_id;
   oauth2_class->get_client_secret         = get_client_secret;
