@@ -28,13 +28,6 @@ struct _GoaHttpClient
   GObject parent_instance;
 };
 
-typedef struct _GoaHttpClientClass GoaHttpClientClass;
-
-struct _GoaHttpClientClass
-{
-  GObjectClass parent_class;
-};
-
 G_DEFINE_TYPE (GoaHttpClient, goa_http_client, G_TYPE_OBJECT);
 
 /* ---------------------------------------------------------------------------------------------------- */
@@ -69,7 +62,7 @@ http_client_log_printer (SoupLogger         *logger,
   gchar *message;
 
   message = g_strdup_printf ("%c %s", direction, data);
-  g_log_default_handler (G_LOG_DOMAIN, G_LOG_LEVEL_DEBUG, message, NULL);
+  g_log_default_handler ("goa", G_LOG_LEVEL_DEBUG, message, NULL);
   g_free (message);
 }
 
