@@ -24,6 +24,7 @@
 #include "goakerberosprovider.h"
 #include "goautils.h"
 #include "goaidentity.h"
+#include "goaidentitymanagererror.h"
 
 #include <gcr/gcr.h>
 
@@ -1582,6 +1583,7 @@ sign_in_identity_sync (GoaKerberosProvider  *self,
   char               *concealed_secret;
   char               *identity_object_path = NULL;
   gboolean            keys_exchanged;
+  GError             *local_error;
   GVariantBuilder     details;
 
   secret_exchange = gcr_secret_exchange_new (NULL);
@@ -1623,12 +1625,27 @@ sign_in_identity_sync (GoaKerberosProvider  *self,
     }
 
   g_mutex_lock (&identity_manager_mutex);
+
+  local_error = NULL;
   goa_identity_service_manager_call_sign_in_sync (identity_manager,
                                                   identifier,
                                                   g_variant_builder_end (&details),
                                                   &identity_object_path,
                                                   cancellable,
-                                                  error);
+                                                  &local_error);
+
+  if (local_error != NULL)
+    {
+      if (g_error_matches (local_error,
+                           GOA_IDENTITY_MANAGER_ERROR,
+                           GOA_IDENTITY_MANAGER_ERROR_ACCESSING_CREDENTIALS))
+        {
+          g_assert_not_reached ();
+        }
+
+      g_propagate_error (error, local_error);
+    }
+
   g_mutex_unlock (&identity_manager_mutex);
 
  out:
@@ -1760,6 +1777,7 @@ goa_kerberos_provider_init (GoaKerberosProvider *provider)
 static void
 goa_kerberos_provider_class_init (GoaKerberosProviderClass *kerberos_class)
 {
+  static volatile GQuark goa_identity_manager_error_domain = 0;
   GoaProviderClass *provider_class;
 
   provider_class = GOA_PROVIDER_CLASS (kerberos_class);
@@ -1774,4 +1792,12 @@ goa_kerberos_provider_class_init (GoaKerberosProviderClass *kerberos_class)
   provider_class->ensure_credentials_sync    = ensure_credentials_sync;
   provider_class->remove_account             = remove_account;
   provider_class->remove_account_finish      = remove_account_finish;
+
+  /* this will force associating errors in the
+   * GOA_IDENTITY_MANAGER_ERROR error domain with
+   * org.gnome.Identity.Manager.Error.* errors via
+   * g_dbus_error_register_error_domain().
+   */
+  goa_identity_manager_error_domain = GOA_IDENTITY_MANAGER_ERROR;
+  goa_identity_manager_error_domain; /* shut up -Wunused-but-set-variable */
 }
