@@ -35,6 +35,7 @@
 #include "goapocketprovider.h"
 #include "goamediaserverprovider.h"
 #include "goalastfmprovider.h"
+#include "goatodoistprovider.h"
 
 #ifdef GOA_KERBEROS_ENABLED
 #include "goakerberosprovider.h"
@@ -172,6 +173,11 @@ static struct {
     .property = "maps-disabled",
     .blurb = N_("_Maps"),
   },
+  {
+    .feature = GOA_PROVIDER_FEATURE_TODO,
+    .property = "todo-disabled",
+    .blurb = N_("T_o Do"),
+  },
   {
     .feature = GOA_PROVIDER_FEATURE_INVALID,
     .property = NULL,
@@ -587,12 +593,17 @@ goa_provider_show_account_real (GoaProvider         *provider,
 
   row = 0;
 
+  goa_utils_account_add_attention_needed (client, object, provider, vbox);
+
   grid = gtk_grid_new ();
   gtk_widget_set_halign (grid, GTK_ALIGN_CENTER);
   gtk_widget_set_hexpand (grid, TRUE);
+  gtk_widget_set_margin_end (grid, 72);
+  gtk_widget_set_margin_start (grid, 72);
+  gtk_widget_set_margin_top (grid, 24);
   gtk_grid_set_column_spacing (GTK_GRID (grid), 12);
   gtk_grid_set_row_spacing (GTK_GRID (grid), 6);
-  gtk_box_pack_start (vbox, grid, FALSE, TRUE, 0);
+  gtk_container_add (GTK_CONTAINER (vbox), grid);
 
   goa_utils_account_add_header (object, GTK_GRID (grid), row++);
 
@@ -612,8 +623,6 @@ goa_provider_show_account_real (GoaProvider         *provider,
           label = NULL;
         }
     }
-
-  goa_utils_account_add_attention_needed (client, object, provider, vbox);
 }
 
 /* ---------------------------------------------------------------------------------------------------- */
@@ -990,6 +999,9 @@ static struct
 #ifdef GOA_LASTFM_ENABLED
   { GOA_LASTFM_NAME, goa_lastfm_provider_get_type },
 #endif
+#ifdef GOA_TODOIST_ENABLED
+  { GOA_TODOIST_NAME, goa_todoist_provider_get_type },
+#endif
 #ifdef GOA_IMAP_SMTP_ENABLED
   { GOA_IMAP_SMTP_NAME, goa_imap_smtp_provider_get_type },
 #endif
