@@ -78,8 +78,8 @@ goa_identity_query_mode_get_type (void)
     return etype;
 }
 
-#include "goaidentitymanager.h"
-/* enumerations from "goaidentitymanager.h" */
+#include "goaidentitymanagererror.h"
+/* enumerations from "goaidentitymanagererror.h" */
 GType goa_identity_manager_error_get_type (void) G_GNUC_CONST;
 
 GType
